| Title: | Impressionism's Color Palettes |
|---|---|
| Description: | Provides color palettes from Impressionism and post-Impressionism artworks. This package allows to select colors combinations while looking at the original paintings where colors were sampled from. |
| Authors: | Federico Casale |
| Maintainer: | Federico Casale <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0 |
| Built: | 2026-05-16 06:03:55 UTC |
| Source: | https://github.com/cran/impressionist.colors |
Provides colors' Hex codes from a specified palette.
get.color(artist, painting, color)get.color(artist, painting, color)
artist |
A number indicating artist. Artists have a numeric order in the package. Check palette.summary to see artists numeric order. |
painting |
A number indicating painting. Paintings have a numeric order in the artist category they belong to. Check palette.summary to see paintings numeric order in each artist category. |
color |
A numeric vector indicating colors. Colors have a numeric order in the palette they belong to. Check see.palette to see colors numeric order in a specified palette. |
Arguments artist and painting cannot be vectorized.
The output is a vector of colors' Hex codes as characters.
Federico A Casale, [email protected]
palette.summary, see.all.paintings, see.palette
get.color(artist=8, painting=2, color=c(1:5)) get.color(8, 2, c(1:5))get.color(artist=8, painting=2, color=c(1:5)) get.color(8, 2, c(1:5))
Prints a summary of all available color palettes in the package categorized by artist and painting along with their numeric order.
palette.summary()palette.summary()
Federico A Casale, [email protected]
see.all.paintings, see.palette, get.color,
palette.summary()palette.summary()
Displays a plot with all paintings included in the package.
see.all.paintings()see.all.paintings()
Federico A Casale, [email protected]
palette.summary, see.palette, get.color
see.all.paintings()see.all.paintings()
Displays a plot with the specified color palette along with the original painting.
see.palette(artist, painting)see.palette(artist, painting)
artist |
A number indicating artist. Artists have a number determined by their order in the package. Check palette.summary to see artists numeric order. |
painting |
A number indicating painting. Paintings have a number determined by their order in the artist category. Check palette.summary to see paintings numeric order in each artist category. |
Arguments artist and painting cannot be vectorized.
Federico A Casale, [email protected]
palette.summary, see.all.paintings, get.color
see.palette(artist=8, painting=2) see.palette(8, 2)see.palette(artist=8, painting=2) see.palette(8, 2)